Learn R Programming

votesmart (version 0.1.2)

measure_get_measures: Get information on a ballot measure

Description

Ballot measure ids can be found with the measure_get_measures_by_year_state function.

Usage

measure_get_measures(measure_ids, verbose = TRUE)

Value

A dataframe with the columns measure_id, measure_code, title, election_date, election_type, outcome, yes_votes, no_votes, summary, summary_url, measure_text, text_url, pro_url, con_url.

Arguments

measure_ids

Vector of ballot measure ids.

verbose

Should cases when no data is available be messaged?

Examples

Run this code
if (FALSE) {
measure_get_measures("1234")
}

Run the code above in your browser using DataLab