powered by
More information about these ballot measures can be found using the measure_get_measures function.
measure_get_measures
measure_get_measures_by_year_state( years = lubridate::year(lubridate::today()), state_ids = state.abb, all = TRUE, verbose = TRUE )
A dataframe of ballot measures and their attributes. If a given year + state_id returns no data, that row will be filled with NAs.
year
state_id
NA
A vector of election years.
A vector of state abbreviations.
Boolean: should all possible combinations of the variables be searched for, or just the exact combination of them in the order they are supplied?
Should cases when no data is available be messaged?
if (FALSE) { measure_get_measures_by_year_state(years = c(2016, 2018), state_ids = c("MO", "IL", "VT")) }
Run the code above in your browser using DataLab