Learn R Programming

votesmart (version 0.1.2)

rating_get_candidate_ratings: Get SIG (Special Interest Group) ratings for candidates

Description

Get SIG (Special Interest Group) ratings for candidates

Usage

rating_get_candidate_ratings(
  candidate_ids,
  sig_ids = "",
  all = TRUE,
  verbose = TRUE
)

Value

A dataframe with the columns rating_id, candidate_id, sig_id, rating, rating_name, timespan, categories, rating_text.

Arguments

candidate_ids

A vector of candidate ids.

sig_ids

A vector of SIG ids. Default is "" for all SIGs.

all

Boolean: should all possible combinations of the variables be searched for, or just the exact combination of them in the order they are supplied?

verbose

Should cases when no data is available be messaged?

Examples

Run this code
if (FALSE) {
pelosi_id <- "26732"
rating_get_candidate_ratings(pelosi_id)
}

Run the code above in your browser using DataLab