powered by
Get SIG (Special Interest Group) list by category and state
rating_get_sig_list(category_ids, state_ids = NA, all = TRUE, verbose = TRUE)
A dataframe with the columns sig_id, name, category_id, state_id.
sig_id, name, category_id, state_id
Vector of category ids.
Vector of state abbreviations. Default NA for national.
NA
Boolean: should all possible combinations of the variables be searched for, or just the exact combination of them in the order they are supplied?
Should cases when no data is available be messaged?
if (FALSE) { rating_get_categories() %>% dplyr::pull(category_id) %>% sample(3) %>% rating_get_sig_list() }
Run the code above in your browser using DataLab