powered by
Get votes by official
votes_get_by_official( candidate_ids, office_ids = "", category_ids = "", years = "", all = TRUE, verbose = TRUE )
A dataframe of candidates' votes on bills and their attributes. If a given input combination returns no data, that row will be filled with NAs.
NA
Vector of candidate_ids (required). See candidates_get_by_lastname, candidates_get_by_levenshtein, and candidates_get_by_office_state.
Vector of office_ids. See office_get_offices_by_level.
Vector of category_ids. See rating_get_categories.
Vector of years in which the vote was taken.
Boolean: should all possible combinations of the variables be searched for, or just the exact combination of them in the order they are supplied?
Should cases when no data is available be messaged?
if (FALSE) { aoc <- candidates_get_by_lastname( "ocasio-cortez", election_years = "2018" ) votes_get_by_official(aoc$candidate_id) }
Run the code above in your browser using DataLab