powered by
Ballot measure ids can be found with the measure_get_measures_by_year_state function.
measure_get_measures_by_year_state
measure_get_measures(measure_ids, verbose = TRUE)
A dataframe with the columns measure_id, measure_code, title, election_date, election_type, outcome, yes_votes, no_votes, summary, summary_url, measure_text, text_url, pro_url, con_url.
measure_id, measure_code, title, election_date, election_type, outcome, yes_votes, no_votes, summary, summary_url, measure_text, text_url, pro_url, con_url
Vector of ballot measure ids.
Should cases when no data is available be messaged?
if (FALSE) { measure_get_measures("1234") }
Run the code above in your browser using DataLab