powered by
Get SIG (Special Interest Group) ratings for candidates
rating_get_candidate_ratings( candidate_ids, sig_ids = "", all = TRUE, verbose = TRUE )
A dataframe with the columns rating_id, candidate_id, sig_id, rating, rating_name, timespan, categories, rating_text.
rating_id, candidate_id, sig_id, rating, rating_name, timespan, categories, rating_text
A vector of candidate ids.
A vector of SIG ids. Default is "" for all SIGs.
""
Boolean: should all possible combinations of the variables be searched for, or just the exact combination of them in the order they are supplied?
Should cases when no data is available be messaged?
if (FALSE) { pelosi_id <- "26732" rating_get_candidate_ratings(pelosi_id) }
Run the code above in your browser using DataLab